package com.example.pda.network

import okhttp3.Interceptor
import okhttp3.OkHttpClient
import okhttp3.logging.HttpLoggingInterceptor
import java.util.concurrent.TimeUnit

object HttpClientWCS {
    // 动态 Token 存储（volatile 保证多线程可见性）
    @Volatile

    var deviceId: Number = 0

    // 认证拦截器（私有保证内部管理）
    private val queryParamsInterceptor = Interceptor { chain ->
        val originalRequest = chain.request()
        val newUrl = originalRequest.url.newBuilder().apply {
            if(deviceId !=0)
            { addQueryParameter("equipmentNumber", deviceId.toString()) }


        }.build()
        chain.proceed(originalRequest.newBuilder().url(newUrl).build())
    }

    // 带动态equipmentNumber  的 OkHttpClient
    val instance: OkHttpClient by lazy {
        OkHttpClient.Builder()
            .connectTimeout(1, TimeUnit.SECONDS)
            .readTimeout(1, TimeUnit.SECONDS)
            .writeTimeout(1, TimeUnit.SECONDS)
            .addInterceptor(queryParamsInterceptor)
            .addInterceptor(HttpLoggingInterceptor().apply {
                level = HttpLoggingInterceptor.Level.BODY // 后添加日志拦截器
            })
            .build()
    }
}